@@ -18,16 +18,18 @@
  */
 
 #include "belle-sip/belle-sip.h"
-#include "belle_sip_tester.h"
 #include "belle_sip_internal.h"
-
+#include "belle_sip_tester.h"
 
 /*test body*/
 #include "belle_sip_base_uri_tester.c"
 
-
-test_suite_t sip_uri_test_suite = {"SIP URI", NULL, NULL, belle_sip_tester_before_each, belle_sip_tester_after_each,
-	sizeof(uri_tests) / sizeof(uri_tests[0]), uri_tests};
-
-
-
+test_suite_t sip_uri_test_suite = {"SIP URI",
+                                   NULL,
+                                   NULL,
+                                   belle_sip_tester_before_each,
+                                   belle_sip_tester_after_each,
+                                   sizeof(uri_tests) / sizeof(uri_tests[0]),
+                                   uri_tests,
+                                   0,
+                                   0};
